from cliche import cli

@cli
def add(a: int, b: int):
    print(a + b)


@cli
def sum_or_multiply(a_number: int, b_number: int = 10, sums: bool = False):
    """ Sums or multiplies a and b

    :param a_number: the first one
    :param b_number: This parameter seems to be
    :param sums: Sums when true, otherwise multiply
    """
    if sums:
        print(a_number + b_number)
    else:
        print(a_number * b_number)



""" File unrelated to the package, except for convenience in deploying """
import re
import sh
import os

commit_count = sh.git('rev-list', ['--all']).count('\n')

with open('setup.py') as f:
    setup = f.read()

setup = re.sub("MICRO_VERSION = '[0-9]+'", "MICRO_VERSION = '{}'".format(commit_count), setup)

major = re.search("MAJOR_VERSION = '([0-9]+)'", setup).groups()[0]
minor = re.search("MINOR_VERSION = '([0-9]+)'", setup).groups()[0]
micro = re.search("MICRO_VERSION = '([0-9]+)'", setup).groups()[0]
version = '{}.{}.{}'.format(major, minor, micro)

with open('setup.py', 'w') as f:
    f.write(setup)

with open('cliche/__init__.py') as f:
    init = f.read()

with open('cliche/__init__.py', 'w') as f:
    f.write(re.sub('__version__ = "[0-9.]+"', '__version__ = "{}"'.format(version), init))

py_version = "python3.7" if sh.which("python3.7") is not None else "python"
os.system('{} setup.py sdist bdist_wheel upload'.format(py_version))



"""Can be called like "python advanced.py" or "cliche advanced.py" """
from cliche import cli, main


@cli
def badd(a_string: str, a_number: int = 10):
    """ Sums a_string and a_number, but we all expect it to fail.

    :param a_string: the first one
    :param a_number: This parameter seems to be
     really good but i don't know tho
    """
    print(a_string + a_number)


@cli
def add(a_number: int, b_number: int = 10):
    print(a_number + b_number)


@cli
def sum_or_multiply(a_number: int, b_number: int = 10, sums: bool = True):
    """ Sums or multiplies a and b

    :param a_number: the first one
    :param b_number: This parameter seems to be
    :param sums: When True, sums instead of multiply
    """
    if sums:
        print(a_number + b_number)
    else:
        print(a_number * b_number)


if __name__ == "__main__":
    main()



from cliche import cli, main


@cli
def a(a=1):
    pass


class A:
    def __init__(self, c, d=1):
        self.c = c
        self.d = d

    @cli
    def printer_a(self):
        print(self.c, self.d)


class B(A):
    @cli
    def printer_a(self, a, b=1):
        print(a, b, self.c, self.d)


if __name__ == "__main__":
    main()



import pytest
from cliche.docstring_to_help import parse_doc_params


def test_google_docstr():
    inp = """
      Args:
          msg (str): Human readable string describing the exception.
          code (:obj:`int`, optional): Error code.
      """
    assert parse_doc_params(inp) == {
        'msg': 'Human readable string describing the exception.',
        'code': 'Error code.',
    }


def test_sphinx_docstr():
    inp = """ Explanation

        :param first: First
        :param second: Second
        """
    assert parse_doc_params(inp) == {
        'first': 'First',
        'second': 'Second',
    }
